@@ -1,73 +1,68 @@
+from autoarray import conf
 from autoarray import preprocess
-from autoarray.mask.mask import Mask
-from autoarray.structures.arrays import Array
-from autoarray.structures.grids import (
-    Grid,
-    GridIrregular,
-    GridRectangular,
-    GridVoronoi,
-    Coordinates,
-)
-from autoarray.structures.kernel import Kernel
-from autoarray.structures.visibilities import Visibilities
-from autoarray.structures.arrays import MaskedArray
-from autoarray.structures.grids import MaskedGrid
 from autoarray.dataset.imaging import Imaging
 from autoarray.dataset.interferometer import Interferometer
+from autoarray.mask.mask import Mask
 from autoarray.operators.convolver import Convolver
+from autoarray.operators.inversion import pixelizations as pix, regularization as reg
+from autoarray.operators.inversion.inversions import inversion as Inversion
+from autoarray.operators.inversion.mappers import mapper as Mapper
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerFFT
 from autoarray.operators.transformer import TransformerNUFFT
-from autoarray.operators.inversion.mappers import mapper as Mapper
-from autoarray.operators.inversion.inversions import inversion as Inversion
-from autoarray.operators.inversion import pixelizations as pix, regularization as reg
-from autoarray import conf
-
-from autoastro import dimensions as dim
-from autoastro import util
-from autoastro.profiles import (
+from autoarray.structures.arrays import Array, Values
+from autoarray.structures.arrays import MaskedArray
+from autoarray.structures.grids import (
+    Grid,
+    GridIterate,
+    GridInterpolate,
+    GridCoordinates,
+    GridRectangular,
+    GridVoronoi,
+)
+from autoarray.structures.grids import MaskedGrid
+from autoarray.structures.kernel import Kernel
+from autoarray.structures.visibilities import Visibilities
+from autogalaxy import dimensions as dim
+from autogalaxy import util
+from autogalaxy.galaxy.fit_galaxy import FitGalaxy
+from autogalaxy.galaxy.galaxy import Galaxy, HyperGalaxy, Redshift
+from autogalaxy.galaxy.galaxy_data import GalaxyData
+from autogalaxy.galaxy.galaxy_model import GalaxyModel
+from autogalaxy.hyper import hyper_data
+from autogalaxy.pipeline.phase.extensions import CombinedHyperPhase
+from autogalaxy.pipeline.phase.extensions import HyperGalaxyPhase
+from autogalaxy.pipeline.phase.extensions.hyper_galaxy_phase import HyperGalaxyPhase
+from autogalaxy.pipeline.phase.extensions.hyper_phase import HyperPhase
+from autogalaxy.pipeline.phase.extensions.inversion_phase import (
+    InversionPhase,
+    ModelFixingHyperPhase,
+)
+from autogalaxy.plane.plane import Plane
+from autogalaxy.profiles import (
     light_profiles as lp,
     mass_profiles as mp,
     light_and_mass_profiles as lmp,
 )
-from autoastro.galaxy.galaxy import Galaxy, HyperGalaxy, Redshift
-from autoastro.galaxy.galaxy_data import GalaxyData
-from autoastro.galaxy.fit_galaxy import FitGalaxy
-from autoastro.galaxy.galaxy_model import GalaxyModel
-from autoastro.hyper import hyper_data
+from autogalaxy.util import convert
 
 from autolens import aggregator as agg
+from autolens import plot
 from autolens.dataset.imaging import MaskedImaging, SimulatorImaging
 from autolens.dataset.interferometer import (
     MaskedInterferometer,
     SimulatorInterferometer,
 )
-from autolens.lens.plane import Plane
-from autolens.lens.ray_tracing import Tracer
-from autolens import util
 from autolens.fit.fit import FitImaging, FitInterferometer
 from autolens.fit.fit import FitPositions
-from autolens.pipeline import tagging
-from autolens.pipeline.phase.abstract import phase
-from autolens.pipeline.phase.abstract.phase import AbstractPhase
-from autolens.pipeline.phase.extensions import CombinedHyperPhase
-from autolens.pipeline.phase.extensions import HyperGalaxyPhase
-from autolens.pipeline.phase.extensions.hyper_galaxy_phase import HyperGalaxyPhase
-from autolens.pipeline.phase.extensions.hyper_phase import HyperPhase
-from autolens.pipeline.phase.extensions.inversion_phase import (
-    InversionBackgroundBothPhase,
-    InversionBackgroundNoisePhase,
-    InversionBackgroundSkyPhase,
-    InversionPhase,
-    ModelFixingHyperPhase,
-)
-from autolens.pipeline.phase.abstract.phase import AbstractPhase
-from autolens.pipeline.phase.dataset.phase import PhaseDataset
+from autolens.lens.ray_tracing import Tracer
+from autolens.pipeline.setup import PipelineSetup
+from autolens.pipeline import slam
+from autolens.pipeline.phase.settings import PhaseSettingsImaging
+from autolens.pipeline.phase.settings import PhaseSettingsInterferometer
 from autolens.pipeline.phase.imaging.phase import PhaseImaging
 from autolens.pipeline.phase.interferometer.phase import PhaseInterferometer
 from autolens.pipeline.phase.phase_galaxy import PhaseGalaxy
 from autolens.pipeline.pipeline import PipelineDataset, PipelinePositions
-from autolens.pipeline import setup
-from autolens import plot
 
-__version__ = '0.45.0'
+__version__ = '1.0.3'
