@@ -2,17 +2,15 @@ from abc import ABC
 
 import numpy as np
 from astropy import cosmology as cosmo
-
-from autoastro import lensing
-from autoarray.util import array_util, grid_util
 from autoarray.mask import mask as msk
-from autoarray.structures import grids
-from autoarray.structures.arrays import MaskedArray
 from autoarray.operators.inversion import inversions as inv
-from autoastro.galaxy import galaxy as g
-from autoastro.util import cosmology_util
-from autolens.lens import plane as pl
-from autolens.util import lens_util
+from autoarray.structures import grids
+from autoarray.util import array_util, grid_util
+from autogalaxy import lensing
+from autogalaxy.galaxy import galaxy as g
+from autogalaxy.plane import plane as pl
+from autogalaxy.util import cosmology_util
+from autogalaxy.util import plane_util
 
 
 class AbstractTracer(lensing.LensingObject, ABC):
@@ -103,19 +101,26 @@ class AbstractTracer(lensing.LensingObject, ABC):
 
     @property
     def light_profile_centres(self):
-        return [
-            item
-            for light_profile_centres in self.light_profile_centres_of_planes
-            for item in light_profile_centres
-        ]
+        """Returns the light profile centres of the tracer as a *GridCoordinates* object, which structures the centres
+        in lists according to which plane they come from.
 
-    @property
-    def light_profile_centres_of_planes(self):
-        return [
-            plane.light_profile_centres
-            for plane in self.planes
-            if plane.has_light_profile
-        ]
+        Fo example, if the tracer has two planes, the first with one light profile and second with two light profiles
+        this returns:
+
+        [[(y0, x0)], [(y0, x0), (y1, x1)]]
+
+        This is used for visualization, for example plotting the centres of all light profiles colored by their galaxy.
+
+        The centres of light-sheets are filtered out, as their centres are not relevant to lensing calculations
+
+        """
+        return grids.GridCoordinates(
+            [
+                list(plane.light_profile_centres)
+                for plane in self.planes
+                if plane.has_light_profile
+            ]
+        )
 
     @property
     def mass_profiles(self):
@@ -131,19 +136,26 @@ class AbstractTracer(lensing.LensingObject, ABC):
 
     @property
     def mass_profile_centres(self):
-        return [
-            item
-            for mass_profile_centres in self.mass_profile_centres_of_planes
-            for item in mass_profile_centres
-        ]
+        """Returns the mass profile centres of the tracer as a *GridCoordinates* object, which structures the centres
+        in lists according to which plane they come from.
 
-    @property
-    def mass_profile_centres_of_planes(self):
-        return [
-            plane.mass_profile_centres
-            for plane in self.planes
-            if plane.has_mass_profile
-        ]
+        Fo example, if the tracer has two planes, the first with one mass profile and second with two mass profiles
+        this returns:
+
+        [[(y0, x0)], [(y0, x0), (y1, x1)]]
+
+        This is used for visualization, for example plotting the centres of all mass profiles colored by their galaxy.
+
+        The centres of mass-sheets are filtered out, as their centres are not relevant to lensing calculations
+
+        """
+        return grids.GridCoordinates(
+            [
+                list(plane.mass_profile_centres)
+                for plane in self.planes
+                if plane.has_mass_profile
+            ]
+        )
 
     @property
     def plane_indexes_with_pixelizations(self):
@@ -229,7 +241,7 @@ class AbstractTracer(lensing.LensingObject, ABC):
 
 class AbstractTracerCosmology(AbstractTracer, ABC):
     def arcsec_per_kpc_proper_of_plane(self, i):
-        return cosmology_util.arcsec_per_kpc_from_redshift_and_cosmology(
+        return cosmology_util.arcsec_per_kpc_from(
             redshift=self.plane_redshifts[i], cosmology=self.cosmology
         )
 
@@ -239,7 +251,7 @@ class AbstractTracerCosmology(AbstractTracer, ABC):
     def angular_diameter_distance_of_plane_to_earth_in_units(
         self, i, unit_length="arcsec"
     ):
-        return cosmology_util.angular_diameter_distance_to_earth_from_redshift_and_cosmology(
+        return cosmology_util.angular_diameter_distance_to_earth_from(
             redshift=self.plane_redshifts[i],
             cosmology=self.cosmology,
             unit_length=unit_length,
@@ -248,7 +260,7 @@ class AbstractTracerCosmology(AbstractTracer, ABC):
     def angular_diameter_distance_between_planes_in_units(
         self, i, j, unit_length="arcsec"
     ):
-        return cosmology_util.angular_diameter_distance_between_redshifts_from_redshifts_and_cosmlology(
+        return cosmology_util.angular_diameter_distance_between_redshifts_from(
             redshift_0=self.plane_redshifts[i],
             redshift_1=self.plane_redshifts[j],
             cosmology=self.cosmology,
@@ -256,7 +268,7 @@ class AbstractTracerCosmology(AbstractTracer, ABC):
         )
 
     def angular_diameter_distance_to_source_plane_in_units(self, unit_length="arcsec"):
-        return cosmology_util.angular_diameter_distance_to_earth_from_redshift_and_cosmology(
+        return cosmology_util.angular_diameter_distance_to_earth_from(
             redshift=self.plane_redshifts[-1],
             cosmology=self.cosmology,
             unit_length=unit_length,
@@ -265,7 +277,7 @@ class AbstractTracerCosmology(AbstractTracer, ABC):
     def critical_surface_density_between_planes_in_units(
         self, i, j, unit_length="arcsec", unit_mass="solMass"
     ):
-        return cosmology_util.critical_surface_density_between_redshifts_from_redshifts_and_cosmology(
+        return cosmology_util.critical_surface_density_between_redshifts_from(
             redshift_0=self.plane_redshifts[i],
             redshift_1=self.plane_redshifts[j],
             cosmology=self.cosmology,
@@ -274,7 +286,7 @@ class AbstractTracerCosmology(AbstractTracer, ABC):
         )
 
     def scaling_factor_between_planes(self, i, j):
-        return cosmology_util.scaling_factor_between_redshifts_from_redshifts_and_cosmology(
+        return cosmology_util.scaling_factor_between_redshifts_from(
             redshift_0=self.plane_redshifts[i],
             redshift_1=self.plane_redshifts[j],
             redshift_final=self.plane_redshifts[-1],
@@ -290,21 +302,19 @@ class AbstractTracerCosmology(AbstractTracer, ABC):
 
 
 class AbstractTracerLensing(AbstractTracerCosmology, ABC):
-    @grids.convert_coordinates_to_grid
+    @grids.grid_like_to_structure_list
     def traced_grids_of_planes_from_grid(self, grid, plane_index_limit=None):
 
-        grid_calc = grid.copy()  # TODO looks unnecessary? Probably pretty expensive too
-
         traced_grids = []
         traced_deflections = []
 
         for (plane_index, plane) in enumerate(self.planes):
 
-            scaled_grid = grid_calc.copy()
+            scaled_grid = grid.copy()
 
             if plane_index > 0:
                 for previous_plane_index in range(plane_index):
-                    scaling_factor = cosmology_util.scaling_factor_between_redshifts_from_redshifts_and_cosmology(
+                    scaling_factor = cosmology_util.scaling_factor_between_redshifts_from(
                         redshift_0=self.plane_redshifts[previous_plane_index],
                         redshift_1=plane.redshift,
                         redshift_final=self.plane_redshifts[-1],
@@ -315,6 +325,8 @@ class AbstractTracerLensing(AbstractTracerCosmology, ABC):
                         scaling_factor * traced_deflections[previous_plane_index]
                     )
 
+                    # TODO : Setup as GridInterpolate
+
                     scaled_grid -= scaled_deflections
 
             traced_grids.append(scaled_grid)
@@ -327,28 +339,26 @@ class AbstractTracerLensing(AbstractTracerCosmology, ABC):
 
         return traced_grids
 
-    @grids.convert_coordinates_to_grid
+    @grids.grid_like_to_structure
     def deflections_between_planes_from_grid(self, grid, plane_i=0, plane_j=-1):
 
         traced_grids_of_planes = self.traced_grids_of_planes_from_grid(grid=grid)
 
         return traced_grids_of_planes[plane_i] - traced_grids_of_planes[plane_j]
 
-    @grids.convert_coordinates_to_grid
-    def profile_image_from_grid(self, grid):
-        profile_image = sum(self.profile_images_of_planes_from_grid(grid=grid))
-        return grid.mapping.array_stored_1d_from_sub_array_1d(
-            sub_array_1d=profile_image
-        )
+    @grids.grid_like_to_structure
+    def image_from_grid(self, grid):
+        return sum(self.images_of_planes_from_grid(grid=grid))
+
+    @grids.grid_like_to_structure_list
+    def images_of_planes_from_grid(self, grid):
 
-    @grids.convert_coordinates_to_grid
-    def profile_images_of_planes_from_grid(self, grid):
         traced_grids_of_planes = self.traced_grids_of_planes_from_grid(
             grid=grid, plane_index_limit=self.upper_plane_index_with_light_profile
         )
 
-        profile_images_of_planes = [
-            self.planes[plane_index].profile_image_from_grid(
+        images_of_planes = [
+            self.planes[plane_index].image_from_grid(
                 grid=traced_grids_of_planes[plane_index]
             )
             for plane_index in range(len(traced_grids_of_planes))
@@ -358,42 +368,31 @@ class AbstractTracerLensing(AbstractTracerCosmology, ABC):
             for plane_index in range(
                 self.upper_plane_index_with_light_profile, self.total_planes - 1
             ):
-                profile_images_of_planes.append(
-                    grid.mapping.array_stored_1d_from_sub_array_1d(
-                        sub_array_1d=np.zeros(shape=profile_images_of_planes[0].shape)
-                    )
-                )
+                images_of_planes.append(np.zeros(shape=images_of_planes[0].shape))
 
-        return profile_images_of_planes
+        return images_of_planes
 
-    def padded_profile_image_from_grid_and_psf_shape(self, grid, psf_shape_2d):
+    def padded_image_from_grid_and_psf_shape(self, grid, psf_shape_2d):
 
         padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf_shape_2d)
 
-        return self.profile_image_from_grid(grid=padded_grid)
+        return self.image_from_grid(grid=padded_grid)
 
-    @grids.convert_coordinates_to_grid
+    @grids.grid_like_to_structure
     def convergence_from_grid(self, grid):
-        convergence = sum(
-            [plane.convergence_from_grid(grid=grid) for plane in self.planes]
-        )
-        return grid.mapping.array_stored_1d_from_sub_array_1d(sub_array_1d=convergence)
+        return sum([plane.convergence_from_grid(grid=grid) for plane in self.planes])
 
-    @grids.convert_coordinates_to_grid
+    @grids.grid_like_to_structure
     def potential_from_grid(self, grid):
-        potential = sum([plane.potential_from_grid(grid=grid) for plane in self.planes])
-        return grid.mapping.array_stored_1d_from_sub_array_1d(sub_array_1d=potential)
+        return sum([plane.potential_from_grid(grid=grid) for plane in self.planes])
 
-    @grids.convert_coordinates_to_grid
+    @grids.grid_like_to_structure
     def deflections_from_grid(self, grid):
         return self.deflections_between_planes_from_grid(grid=grid)
 
-    @grids.convert_coordinates_to_grid
+    @grids.grid_like_to_structure
     def deflections_of_planes_summed_from_grid(self, grid):
-        deflections = sum(
-            [plane.deflections_from_grid(grid=grid) for plane in self.planes]
-        )
-        return grid.mapping.grid_stored_1d_from_sub_grid_1d(sub_grid_1d=deflections)
+        return sum([plane.deflections_from_grid(grid=grid) for plane in self.planes])
 
     def grid_at_redshift_from_grid_and_redshift(self, grid, redshift):
         """For an input grid of (y,x) arc-second image-plane coordinates, ray-trace the coordinates to any redshift in \
@@ -445,7 +444,7 @@ class AbstractTracerLensing(AbstractTracerCosmology, ABC):
             self.image_plane_multiple_image_positions(
                 grid=grid, source_plane_coordinate=light_profile_centre
             )
-            for light_profile_centre in self.light_profile_centres_of_planes[-1]
+            for light_profile_centre in self.light_profile_centres.in_list[-1]
         ]
 
     def image_plane_multiple_image_positions(self, grid, source_plane_coordinate):
@@ -461,8 +460,8 @@ class AbstractTracerLensing(AbstractTracerCosmology, ABC):
             coordinate=source_plane_coordinate
         )
 
-        trough_pixels = array_util.trough_pixels_from_array_2d(
-            array_2d=source_plane_squared_distances.in_2d, mask_2d=grid.mask
+        trough_pixels = array_util.trough_pixels_from(
+            array_2d=source_plane_squared_distances.in_2d, mask=grid.mask
         )
 
         trough_mask = msk.Mask.from_pixel_coordinates(
@@ -474,14 +473,17 @@ class AbstractTracerLensing(AbstractTracerCosmology, ABC):
             buffer=1,
         )
 
-        multiple_image_pixels = grid_util.positions_at_coordinate_from_grid_2d(
+        multiple_image_pixels = grid_util.positions_at_coordinate_from(
             grid_2d=source_plane_grid.in_2d,
             coordinate=source_plane_coordinate,
-            mask_2d=trough_mask,
+            mask=trough_mask,
         )
 
-        return grids.Coordinates.from_pixels_and_mask(
-            pixels=[multiple_image_pixels], mask=trough_mask
+        return list(
+            map(
+                trough_mask.geometry.scaled_coordinates_from_pixel_coordinates,
+                multiple_image_pixels,
+            )
         )
 
     @property
@@ -515,7 +517,7 @@ class AbstractTracerLensing(AbstractTracerCosmology, ABC):
 
 
 class AbstractTracerData(AbstractTracerLensing, ABC):
-    def blurred_profile_image_from_grid_and_psf(self, grid, psf, blurring_grid):
+    def blurred_image_from_grid_and_psf(self, grid, psf, blurring_grid):
         """Extract the 1D image and 1D blurring image of every plane and blur each with the \
         PSF using a psf (see imaging.convolution).
 
@@ -527,18 +529,15 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
             Class which performs the PSF convolution of a masked image in 1D.
         """
 
-        profile_image = self.profile_image_from_grid(grid=grid)
+        image = self.image_from_grid(grid=grid)
 
-        blurring_image = self.profile_image_from_grid(grid=blurring_grid)
+        blurring_image = self.image_from_grid(grid=blurring_grid)
 
         return psf.convolved_array_from_array_2d_and_mask(
-            array_2d=profile_image.in_2d_binned + blurring_image.in_2d_binned,
-            mask=grid.mask,
+            array_2d=image.in_2d_binned + blurring_image.in_2d_binned, mask=grid.mask
         )
 
-    def blurred_profile_images_of_planes_from_grid_and_psf(
-        self, grid, psf, blurring_grid
-    ):
+    def blurred_images_of_planes_from_grid_and_psf(self, grid, psf, blurring_grid):
         """Extract the 1D image and 1D blurring image of every plane and blur each with the \
         PSF using a psf (see imaging.convolution).
 
@@ -554,9 +553,8 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         traced_blurring_grids_of_planes = self.traced_grids_of_planes_from_grid(
             grid=blurring_grid
         )
-
         return [
-            plane.blurred_profile_image_from_grid_and_psf(
+            plane.blurred_image_from_grid_and_psf(
                 grid=traced_grids_of_planes[plane_index],
                 psf=psf,
                 blurring_grid=traced_blurring_grids_of_planes[plane_index],
@@ -564,9 +562,7 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
             for (plane_index, plane) in enumerate(self.planes)
         ]
 
-    def blurred_profile_image_from_grid_and_convolver(
-        self, grid, convolver, blurring_grid
-    ):
+    def blurred_image_from_grid_and_convolver(self, grid, convolver, blurring_grid):
         """Extract the 1D image and 1D blurring image of every plane and blur each with the \
         PSF using a convolver (see imaging.convolution).
 
@@ -578,15 +574,15 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
             Class which performs the PSF convolution of a masked image in 1D.
         """
 
-        profile_image = self.profile_image_from_grid(grid=grid)
+        image = self.image_from_grid(grid=grid)
 
-        blurring_image = self.profile_image_from_grid(grid=blurring_grid)
+        blurring_image = self.image_from_grid(grid=blurring_grid)
 
         return convolver.convolved_image_from_image_and_blurring_image(
-            image=profile_image, blurring_image=blurring_image
+            image=image, blurring_image=blurring_image
         )
 
-    def blurred_profile_images_of_planes_from_grid_and_convolver(
+    def blurred_images_of_planes_from_grid_and_convolver(
         self, grid, convolver, blurring_grid
     ):
         """Extract the 1D image and 1D blurring image of every plane and blur each with the \
@@ -606,7 +602,7 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         )
 
         return [
-            plane.blurred_profile_image_from_grid_and_convolver(
+            plane.blurred_image_from_grid_and_convolver(
                 grid=traced_grids_of_planes[plane_index],
                 convolver=convolver,
                 blurring_grid=traced_blurring_grids_of_planes[plane_index],
@@ -614,53 +610,53 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
             for (plane_index, plane) in enumerate(self.planes)
         ]
 
-    def unmasked_blurred_profile_image_from_grid_and_psf(self, grid, psf):
+    def unmasked_blurred_image_from_grid_and_psf(self, grid, psf):
 
         padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf.shape_2d)
 
-        padded_image = self.profile_image_from_grid(grid=padded_grid)
+        padded_image = self.image_from_grid(grid=padded_grid)
 
-        return padded_grid.mapping.unmasked_blurred_array_from_padded_array_psf_and_image_shape(
+        return padded_grid.mask.unmasked_blurred_array_from_padded_array_psf_and_image_shape(
             padded_array=padded_image, psf=psf, image_shape=grid.mask.shape
         )
 
-    def unmasked_blurred_profile_image_of_planes_from_grid_and_psf(self, grid, psf):
+    def unmasked_blurred_image_of_planes_from_grid_and_psf(self, grid, psf):
 
         padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf.shape_2d)
 
         traced_padded_grids = self.traced_grids_of_planes_from_grid(grid=padded_grid)
 
-        unmasked_blurred_profile_images_of_planes = []
+        unmasked_blurred_images_of_planes = []
 
         for plane, traced_padded_grid in zip(self.planes, traced_padded_grids):
-            padded_image_1d = plane.profile_image_from_grid(grid=traced_padded_grid)
+            padded_image_1d = plane.image_from_grid(grid=traced_padded_grid)
 
-            unmasked_blurred_array_2d = padded_grid.mapping.unmasked_blurred_array_from_padded_array_psf_and_image_shape(
+            unmasked_blurred_array_2d = padded_grid.mask.unmasked_blurred_array_from_padded_array_psf_and_image_shape(
                 padded_array=padded_image_1d, psf=psf, image_shape=grid.mask.shape
             )
 
-            unmasked_blurred_profile_images_of_planes.append(unmasked_blurred_array_2d)
+            unmasked_blurred_images_of_planes.append(unmasked_blurred_array_2d)
 
-        return unmasked_blurred_profile_images_of_planes
+        return unmasked_blurred_images_of_planes
 
-    def unmasked_blurred_profile_image_of_planes_and_galaxies_from_grid_and_psf(
+    def unmasked_blurred_image_of_planes_and_galaxies_from_grid_and_psf(
         self, grid, psf
     ):
 
-        unmasked_blurred_profile_images_of_planes_and_galaxies = []
+        unmasked_blurred_images_of_planes_and_galaxies = []
 
         padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf.shape_2d)
 
         traced_padded_grids = self.traced_grids_of_planes_from_grid(grid=padded_grid)
 
         for plane, traced_padded_grid in zip(self.planes, traced_padded_grids):
-            padded_image_1d_of_galaxies = plane.profile_images_of_galaxies_from_grid(
+            padded_image_1d_of_galaxies = plane.images_of_galaxies_from_grid(
                 grid=traced_padded_grid
             )
 
             unmasked_blurred_array_2d_of_galaxies = list(
                 map(
-                    lambda padded_image_1d_of_galaxy: padded_grid.mapping.unmasked_blurred_array_from_padded_array_psf_and_image_shape(
+                    lambda padded_image_1d_of_galaxy: padded_grid.mask.unmasked_blurred_array_from_padded_array_psf_and_image_shape(
                         padded_array=padded_image_1d_of_galaxy,
                         psf=psf,
                         image_shape=grid.mask.shape,
@@ -669,45 +665,50 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
                 )
             )
 
-            unmasked_blurred_profile_images_of_planes_and_galaxies.append(
+            unmasked_blurred_images_of_planes_and_galaxies.append(
                 unmasked_blurred_array_2d_of_galaxies
             )
 
-        return unmasked_blurred_profile_images_of_planes_and_galaxies
+        return unmasked_blurred_images_of_planes_and_galaxies
 
     def profile_visibilities_from_grid_and_transformer(self, grid, transformer):
 
-        profile_image = self.profile_image_from_grid(grid=grid)
-        return transformer.visibilities_from_image(image=profile_image)
+        image = self.image_from_grid(grid=grid)
+
+        return transformer.visibilities_from_image(image=image)
 
     def profile_visibilities_of_planes_from_grid_and_transformer(
         self, grid, transformer
     ):
 
-        profile_images_of_planes = self.profile_images_of_planes_from_grid(grid=grid)
+        images_of_planes = self.images_of_planes_from_grid(grid=grid)
         return [
-            transformer.visibilities_from_image(image=profile_image)
-            for profile_image in profile_images_of_planes
+            transformer.visibilities_from_image(image=image)
+            for image in images_of_planes
         ]
 
-    def sparse_image_plane_grids_of_planes_from_grid(self, grid):
+    def sparse_image_plane_grids_of_planes_from_grid(
+        self, grid, inversion_stochastic=False
+    ):
 
         sparse_image_plane_grids_of_planes = []
 
         for plane in self.planes:
-            sparse_image_plane_grid = plane.sparse_image_plane_grid_from_grid(grid=grid)
+            sparse_image_plane_grid = plane.sparse_image_plane_grid_from_grid(
+                grid=grid, inversion_stochastic=inversion_stochastic
+            )
             sparse_image_plane_grids_of_planes.append(sparse_image_plane_grid)
 
         return sparse_image_plane_grids_of_planes
 
     def traced_sparse_grids_of_planes_from_grid(
-        self, grid, preload_sparse_grids_of_planes=None
+        self, grid, preload_sparse_grids_of_planes=None, inversion_stochastic=False
     ):
 
-        if preload_sparse_grids_of_planes is None:
+        if preload_sparse_grids_of_planes is None or inversion_stochastic:
 
             sparse_image_plane_grids_of_planes = self.sparse_image_plane_grids_of_planes_from_grid(
-                grid=grid
+                grid=grid, inversion_stochastic=inversion_stochastic
             )
 
         else:
@@ -729,7 +730,11 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         return traced_sparse_grids_of_planes
 
     def mappers_of_planes_from_grid(
-        self, grid, inversion_uses_border=False, preload_sparse_grids_of_planes=None
+        self,
+        grid,
+        inversion_uses_border=False,
+        preload_sparse_grids_of_planes=None,
+        inversion_stochastic=False,
     ):
 
         mappers_of_planes = []
@@ -737,7 +742,9 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         traced_grids_of_planes = self.traced_grids_of_planes_from_grid(grid=grid)
 
         traced_sparse_grids_of_planes = self.traced_sparse_grids_of_planes_from_grid(
-            grid=grid, preload_sparse_grids_of_planes=preload_sparse_grids_of_planes
+            grid=grid,
+            preload_sparse_grids_of_planes=preload_sparse_grids_of_planes,
+            inversion_stochastic=inversion_stochastic,
         )
 
         for (plane_index, plane) in enumerate(self.planes):
@@ -762,12 +769,14 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         convolver,
         inversion_uses_border=False,
         preload_sparse_grids_of_planes=None,
+        inversion_stochastic=False,
     ):
 
         mappers_of_planes = self.mappers_of_planes_from_grid(
             grid=grid,
             inversion_uses_border=inversion_uses_border,
             preload_sparse_grids_of_planes=preload_sparse_grids_of_planes,
+            inversion_stochastic=inversion_stochastic,
         )
 
         return inv.InversionImaging.from_data_mapper_and_regularization(
@@ -786,11 +795,13 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         transformer,
         inversion_uses_border=False,
         preload_sparse_grids_of_planes=None,
+        inversion_stochastic=False,
     ):
         mappers_of_planes = self.mappers_of_planes_from_grid(
             grid=grid,
             inversion_uses_border=inversion_uses_border,
             preload_sparse_grids_of_planes=preload_sparse_grids_of_planes,
+            inversion_stochastic=inversion_stochastic,
         )
 
         return inv.InversionInterferometer.from_data_mapper_and_regularization(
@@ -813,34 +824,32 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
             for plane in self.planes
         ]
 
-    def galaxy_profile_image_dict_from_grid(self, grid) -> {g.Galaxy: np.ndarray}:
+    def galaxy_image_dict_from_grid(self, grid) -> {g.Galaxy: np.ndarray}:
         """
         A dictionary associating galaxies with their corresponding model images
         """
 
-        galaxy_profile_image_dict = dict()
+        galaxy_image_dict = dict()
 
         traced_grids_of_planes = self.traced_grids_of_planes_from_grid(grid=grid)
 
         for (plane_index, plane) in enumerate(self.planes):
-            profile_images_of_galaxies = plane.profile_images_of_galaxies_from_grid(
+            images_of_galaxies = plane.images_of_galaxies_from_grid(
                 grid=traced_grids_of_planes[plane_index]
             )
             for (galaxy_index, galaxy) in enumerate(plane.galaxies):
-                galaxy_profile_image_dict[galaxy] = profile_images_of_galaxies[
-                    galaxy_index
-                ]
+                galaxy_image_dict[galaxy] = images_of_galaxies[galaxy_index]
 
-        return galaxy_profile_image_dict
+        return galaxy_image_dict
 
-    def galaxy_blurred_profile_image_dict_from_grid_and_convolver(
+    def galaxy_blurred_image_dict_from_grid_and_convolver(
         self, grid, convolver, blurring_grid
     ) -> {g.Galaxy: np.ndarray}:
         """
         A dictionary associating galaxies with their corresponding model images
         """
 
-        galaxy_blurred_profile_image_dict = dict()
+        galaxy_blurred_image_dict = dict()
 
         traced_grids_of_planes = self.traced_grids_of_planes_from_grid(grid=grid)
 
@@ -849,17 +858,17 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         )
 
         for (plane_index, plane) in enumerate(self.planes):
-            blurred_profile_images_of_galaxies = plane.blurred_profile_images_of_galaxies_from_grid_and_convolver(
+            blurred_images_of_galaxies = plane.blurred_images_of_galaxies_from_grid_and_convolver(
                 grid=traced_grids_of_planes[plane_index],
                 convolver=convolver,
                 blurring_grid=traced_blurring_grids_of_planes[plane_index],
             )
             for (galaxy_index, galaxy) in enumerate(plane.galaxies):
-                galaxy_blurred_profile_image_dict[
-                    galaxy
-                ] = blurred_profile_images_of_galaxies[galaxy_index]
+                galaxy_blurred_image_dict[galaxy] = blurred_images_of_galaxies[
+                    galaxy_index
+                ]
 
-        return galaxy_blurred_profile_image_dict
+        return galaxy_blurred_image_dict
 
     def galaxy_profile_visibilities_dict_from_grid_and_transformer(
         self, grid, transformer
@@ -888,11 +897,9 @@ class Tracer(AbstractTracerData):
     @classmethod
     def from_galaxies(cls, galaxies, cosmology=cosmo.Planck15):
 
-        plane_redshifts = lens_util.ordered_plane_redshifts_from_galaxies(
-            galaxies=galaxies
-        )
+        plane_redshifts = plane_util.ordered_plane_redshifts_from(galaxies=galaxies)
 
-        galaxies_in_planes = lens_util.galaxies_in_redshift_ordered_planes_from_galaxies(
+        galaxies_in_planes = plane_util.galaxies_in_redshift_ordered_planes_from(
             galaxies=galaxies, plane_redshifts=plane_redshifts
         )
 
@@ -942,17 +949,15 @@ class Tracer(AbstractTracerData):
             The cosmology of the ray-tracing calculation.
         """
 
-        lens_redshifts = lens_util.ordered_plane_redshifts_from_galaxies(
-            galaxies=lens_galaxies
-        )
+        lens_redshifts = plane_util.ordered_plane_redshifts_from(galaxies=lens_galaxies)
 
-        plane_redshifts = lens_util.ordered_plane_redshifts_from_lens_source_plane_redshifts_and_slice_sizes(
+        plane_redshifts = plane_util.ordered_plane_redshifts_with_slicing_from(
             lens_redshifts=lens_redshifts,
             planes_between_lenses=planes_between_lenses,
             source_plane_redshift=source_galaxies[0].redshift,
         )
 
-        galaxies_in_planes = lens_util.galaxies_in_redshift_ordered_planes_from_galaxies(
+        galaxies_in_planes = plane_util.galaxies_in_redshift_ordered_planes_from(
             galaxies=lens_galaxies + line_of_sight_galaxies,
             plane_redshifts=plane_redshifts,
         )
