@@ -1,16 +1,26 @@
 import autofit as af
 from autoarray.exc import InversionException
-from autoastro.galaxy import galaxy as g
 from autofit.exc import FitException
+from autogalaxy.galaxy import galaxy as g
+from autogalaxy.pipeline.phase.dataset import analysis as ag_analysis
 from autolens.fit import fit
 from autolens.pipeline import visualizer
-from autolens.pipeline.phase.dataset import analysis as analysis_data
+from autolens.pipeline.phase.dataset import analysis as analysis_dataset
 
 
-class Analysis(analysis_data.Analysis):
-    def __init__(self, masked_interferometer, cosmology, image_path=None, results=None):
+class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
+    def __init__(
+        self,
+        masked_interferometer,
+        cosmology,
+        image_path=None,
+        results=None,
+        log_likelihood_cap=None,
+    ):
 
-        super(Analysis, self).__init__(cosmology=cosmology, results=results)
+        super(Analysis, self).__init__(
+            cosmology=cosmology, results=results, log_likelihood_cap=log_likelihood_cap
+        )
 
         self.visualizer = visualizer.PhaseInterferometerVisualizer(
             masked_dataset=masked_interferometer, image_path=image_path
@@ -23,7 +33,7 @@ class Analysis(analysis_data.Analysis):
 
         self.masked_dataset = masked_interferometer
 
-        result = analysis_data.last_result_with_use_as_hyper_dataset(results=results)
+        result = ag_analysis.last_result_with_use_as_hyper_dataset(results=results)
 
         if result is not None:
 
@@ -42,7 +52,7 @@ class Analysis(analysis_data.Analysis):
     def masked_interferometer(self):
         return self.masked_dataset
 
-    def fit(self, instance):
+    def log_likelihood_function(self, instance):
         """
         Determine the fit of a lens galaxy and source galaxy to the masked_interferometer in this lens.
 
