@@ -1,14 +1,15 @@
-from astropy import cosmology as cosmo
-
 import autofit as af
+from astropy import cosmology as cosmo
 from autoarray.operators import transformer
-from autolens.pipeline import tagging
-from autolens.pipeline.phase import dataset
+from autogalaxy.pipeline.phase import dataset
+from autogalaxy.pipeline.phase.interferometer.phase import (
+    PhaseAttributes as AgPhaseAttributes,
+)
+from autolens.pipeline.phase.settings import PhaseSettingsInterferometer
 from autolens.pipeline.phase.interferometer.analysis import Analysis
 from autolens.pipeline.phase.interferometer.meta_interferometer import (
     MetaInterferometer,
 )
-
 from autolens.pipeline.phase.interferometer.result import Result
 
 
@@ -24,48 +25,34 @@ class PhaseInterferometer(dataset.PhaseDataset):
         self,
         paths,
         *,
+        search,
         real_space_mask,
-        transformer_class=transformer.TransformerNUFFT,
         galaxies=None,
         hyper_background_noise=None,
-        non_linear_class=af.MultiNest,
+        settings=PhaseSettingsInterferometer(),
         cosmology=cosmo.Planck15,
-        sub_size=2,
-        primary_beam_shape_2d=None,
-        auto_positions_factor=None,
-        positions_threshold=None,
-        pixel_scale_interpolation_grid=None,
-        inversion_uses_border=True,
-        inversion_pixel_limit=None,
     ):
 
         """
 
-        A phase in an lens pipeline. Uses the set non_linear optimizer to try to fit models and hyper_galaxies
+        A phase in an lens pipeline. Uses the set non_linear search to try to fit models and hyper_galaxies
         passed to it.
 
         Parameters
         ----------
-        non_linear_class: class
-            The class of a non_linear optimizer
+        search: class
+            The class of a non_linear search
         sub_size: int
             The side length of the subgrid
         """
 
-        paths.phase_tag = tagging.phase_tag_from_phase_settings(
-            sub_size=sub_size,
-            real_space_shape_2d=real_space_mask.shape_2d,
-            real_space_pixel_scales=real_space_mask.pixel_scales,
-            primary_beam_shape_2d=primary_beam_shape_2d,
-            auto_positions_factor=auto_positions_factor,
-            positions_threshold=positions_threshold,
-            pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
-        )
+        paths.tag = settings.phase_with_inversion_tag
 
         super().__init__(
-            paths,
+            paths=paths,
+            search=search,
             galaxies=galaxies,
-            non_linear_class=non_linear_class,
+            settings=settings,
             cosmology=cosmology,
         )
 
@@ -74,16 +61,10 @@ class PhaseInterferometer(dataset.PhaseDataset):
         self.is_hyper_phase = False
 
         self.meta_dataset = MetaInterferometer(
+            settings=settings,
             model=self.model,
-            sub_size=sub_size,
             real_space_mask=real_space_mask,
-            transformer_class=transformer_class,
-            primary_beam_shape_2d=primary_beam_shape_2d,
-            auto_positions_factor=auto_positions_factor,
-            positions_threshold=positions_threshold,
-            pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
-            inversion_uses_border=inversion_uses_border,
-            inversion_pixel_limit=inversion_pixel_limit,
+            is_hyper_phase=False,
         )
 
     # noinspection PyMethodMayBeStatic,PyUnusedLocal
@@ -105,9 +86,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
         """
         return visibilities
 
-    def make_analysis(
-        self, dataset, mask, results=af.ResultsCollection(), positions=None
-    ):
+    def make_analysis(self, dataset, mask, results=None):
         """
         Create an lens object. Also calls the prior passing and masked_interferometer modifying functions to allow child
         classes to change the behaviour of the phase.
@@ -125,7 +104,7 @@ class PhaseInterferometer(dataset.PhaseDataset):
         Returns
         -------
         lens : Analysis
-            An lens object that the non-linear optimizer calls to determine the fit of a set of values
+            An lens object that the non-linear search calls to determine the fit of a set of values
         """
         self.meta_dataset.model = self.model
         modified_visibilities = self.modify_visibilities(
@@ -135,7 +114,6 @@ class PhaseInterferometer(dataset.PhaseDataset):
         masked_interferometer = self.meta_dataset.masked_dataset_from(
             dataset=dataset,
             mask=mask,
-            positions=positions,
             results=results,
             modified_visibilities=modified_visibilities,
         )
@@ -145,32 +123,38 @@ class PhaseInterferometer(dataset.PhaseDataset):
         analysis = self.Analysis(
             masked_interferometer=masked_interferometer,
             cosmology=self.cosmology,
-            image_path=self.optimizer.paths.image_path,
+            image_path=self.search.paths.image_path,
             results=results,
+            log_likelihood_cap=self.settings.log_likelihood_cap,
         )
 
         return analysis
 
     def make_phase_attributes(self, analysis):
-        return PhaseAttributes(cosmology=self.cosmology)
+        return PhaseAttributes(
+            cosmology=self.cosmology,
+            positions=analysis.masked_dataset.positions,
+            hyper_model_image=analysis.hyper_model_image,
+            hyper_galaxy_image_path_dict=analysis.hyper_galaxy_image_path_dict,
+        )
 
     def output_phase_info(self):
 
-        file_phase_info = "{}/{}".format(
-            self.optimizer.paths.phase_output_path, "phase.info"
-        )
+        file_phase_info = "{}/{}".format(self.search.paths.output_path, "phase.info")
 
         with open(file_phase_info, "w") as phase_info:
-            phase_info.write("Optimizer = {} \n".format(type(self.optimizer).__name__))
-            phase_info.write("Sub-grid size = {} \n".format(self.meta_dataset.sub_size))
+            phase_info.write("Optimizer = {} \n".format(type(self.search).__name__))
+            phase_info.write(
+                "Sub-grid size = {} \n".format(self.meta_dataset.settings.sub_size)
+            )
             phase_info.write(
                 "Primary Beam shape = {} \n".format(
-                    self.meta_dataset.primary_beam_shape_2d
+                    self.meta_dataset.settings.primary_beam_shape_2d
                 )
             )
             phase_info.write(
                 "Positions Threshold = {} \n".format(
-                    self.meta_dataset.positions_threshold
+                    self.meta_dataset.settings.positions_threshold
                 )
             )
             phase_info.write("Cosmology = {} \n".format(self.cosmology))
@@ -178,7 +162,15 @@ class PhaseInterferometer(dataset.PhaseDataset):
             phase_info.close()
 
 
-class PhaseAttributes:
-    def __init__(self, cosmology):
+class PhaseAttributes(AgPhaseAttributes):
+    def __init__(
+        self, cosmology, positions, hyper_model_image, hyper_galaxy_image_path_dict
+    ):
 
-        self.cosmology = cosmology
+        super().__init__(
+            cosmology=cosmology,
+            hyper_model_image=hyper_model_image,
+            hyper_galaxy_image_path_dict=hyper_galaxy_image_path_dict,
+        )
+
+        self.positions = positions
