@@ -4,29 +4,25 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source"
 test_name = "lens_mass__source_x2"
-data_type = "lens_sie__source_smooth"
-data_resolution = "euclid"
+data_name = "lens_sie__source_smooth"
+instrument = "euclid"
 
 
-def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
+def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
             source_0=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase1.optimizer.const_efficiency_mode = True
-    phase1.optimizer.n_live_points = 60
-    phase1.optimizer.sampling_efficiency = 0.7
-
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase1.result.model.galaxies.lens.mass
@@ -36,13 +32,9 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
             ),
             source_1=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase2.optimizer.const_efficiency_mode = True
-    phase2.optimizer.n_live_points = 60
-    phase2.optimizer.sampling_efficiency = 0.7
-
     return al.PipelineDataset(name, phase1, phase2)
 
 
