@@ -4,29 +4,29 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source"
 test_name = "lens_mass__source_x2__hyper"
-data_type = "lens_sie__source_smooth"
-data_resolution = "lsst"
+data_name = "lens_sie__source_smooth"
+instrument = "vro"
 
 
-def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
+def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
             source_0=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase1.optimizer.const_efficiency_mode = True
-    phase1.optimizer.n_live_points = 60
-    phase1.optimizer.sampling_efficiency = 0.7
+    phase1.search.const_efficiency_mode = True
+    phase1.search.n_live_points = 60
+    phase1.search.sampling_efficiency = 0.7
 
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase1.result.model.galaxies.lens.mass
@@ -36,14 +36,14 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
             ),
             source_1=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase2.optimizer.const_efficiency_mode = True
-    phase2.optimizer.n_live_points = 60
-    phase2.optimizer.sampling_efficiency = 0.7
+    phase2.search.const_efficiency_mode = True
+    phase2.search.n_live_points = 60
+    phase2.search.sampling_efficiency = 0.7
 
-    phase2 = phase2.extend_with_multiple_hyper_phases(hyper_galaxy=True)
+    phase2 = phase2.extend_with_multiple_hyper_phases(hyper_galaxies_search=True)
 
     class HyperLensSourcePlanePhase(al.PhaseImaging):
         def customize_priors(self, results):
@@ -58,7 +58,7 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
 
     phase3 = HyperLensSourcePlanePhase(
         phase_name="phase_3",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase2.result.model.galaxies.lens.mass
@@ -74,12 +74,12 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
                 hyper_galaxy=phase2.result.hyper_combined.instance.galaxies.source_1.hyper_galaxy,
             ),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase3.optimizer.const_efficiency_mode = True
-    phase3.optimizer.n_live_points = 40
-    phase3.optimizer.sampling_efficiency = 0.8
+    phase3.search.const_efficiency_mode = True
+    phase3.search.n_live_points = 40
+    phase3.search.sampling_efficiency = 0.8
 
     return al.PipelineDataset(name, phase1, phase2, phase3)
 
