@@ -4,15 +4,15 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source_inversion"
 test_name = "lens_mass__source_adaptive_magnification"
-data_type = "lens_sie__source_smooth"
-data_resolution = "euclid"
+data_name = "lens_sie__source_smooth"
+instrument = "euclid"
 
 
-def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
+def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
             source=al.GalaxyModel(
@@ -21,18 +21,18 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
                 regularization=al.reg.Constant,
             ),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase1.optimizer.const_efficiency_mode = True
-    phase1.optimizer.n_live_points = 60
-    phase1.optimizer.sampling_efficiency = 0.8
+    phase1.search.const_efficiency_mode = True
+    phase1.search.n_live_points = 60
+    phase1.search.sampling_efficiency = 0.8
 
     phase1 = phase1.extend_with_inversion_phase()
 
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase1.result.model.galaxies.lens.mass
@@ -43,16 +43,16 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
                 regularization=phase1.result.instance.galaxies.source.regularization,
             ),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase2.optimizer.const_efficiency_mode = True
-    phase2.optimizer.n_live_points = 60
-    phase2.optimizer.sampling_efficiency = 0.8
+    phase2.search.const_efficiency_mode = True
+    phase2.search.n_live_points = 60
+    phase2.search.sampling_efficiency = 0.8
 
     phase2 = phase2.extend_with_inversion_phase()
 
-    return al.PipelineDataset(name, phase1)  # , phase2)
+    return al.PipelineDataset(name, phase1, phase2)
 
 
 if __name__ == "__main__":
