@@ -4,41 +4,41 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source_inversion"
 test_name = "lens_mass__source_adaptive_magnification__offset_centre"
-data_type = "lens_sie__source_smooth__offset_centre"
-data_resolution = "lsst"
+data_name = "lens_sie__source_smooth__offset_centre"
+instrument = "vro"
 
 
-def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
-    class SourcePix(al.PhaseImaging):
-        def customize_priors(self, results):
+def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
-            self.galaxies.lens.mass.centre.centre_0 = 2.0
-            self.galaxies.lens.mass.centre.centre_1 = 2.0
-            self.galaxies.lens.mass.einstein_radius = 1.2
+    mass = af.PriorModel(al.mp.EllipticalIsothermal)
 
-    phase1 = SourcePix(
+    mass.centre.centre_0 = 2.0
+    mass.centre.centre_1 = 2.0
+    mass.einstein_radius = 1.6
+
+    phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
-            lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
+            lens=al.GalaxyModel(redshift=0.5, mass=mass),
             source=al.GalaxyModel(
                 redshift=1.0,
                 pixelization=al.pix.VoronoiMagnification,
                 regularization=al.reg.Constant,
             ),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase1.optimizer.const_efficiency_mode = True
-    phase1.optimizer.n_live_points = 60
-    phase1.optimizer.sampling_efficiency = 0.8
+    phase1.search.const_efficiency_mode = True
+    phase1.search.n_live_points = 60
+    phase1.search.sampling_efficiency = 0.8
 
     phase1 = phase1.extend_with_inversion_phase()
 
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase1.result.model.galaxies.lens.mass
@@ -49,12 +49,12 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
                 regularization=phase1.result.inversion.instance.galaxies.source.regularization,
             ),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase2.optimizer.const_efficiency_mode = True
-    phase2.optimizer.n_live_points = 60
-    phase2.optimizer.sampling_efficiency = 0.8
+    phase2.search.const_efficiency_mode = True
+    phase2.search.n_live_points = 60
+    phase2.search.sampling_efficiency = 0.8
 
     phase2 = phase2.extend_with_inversion_phase()
 
