@@ -4,41 +4,41 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "lens__source_inversion"
 test_name = "lens_mass__source_rectangular__hyper"
-data_type = "lens_sie__source_smooth"
-data_resolution = "lsst"
+data_name = "lens_sie__source_smooth"
+instrument = "vro"
 
 
-def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
-    class SourcePix(al.PhaseImaging):
-        def customize_priors(self, results):
+def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
-            self.galaxies.lens.mass.centre.centre_0 = 0.0
-            self.galaxies.lens.mass.centre.centre_1 = 0.0
-            self.galaxies.lens.mass.einstein_radius = 1.6
+    mass = af.PriorModel(al.mp.EllipticalIsothermal)
 
-    phase1 = SourcePix(
+    mass.centre.centre_0 = 0.0
+    mass.centre.centre_1 = 0.0
+    mass.einstein_radius = 1.6
+
+    phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
-            lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
+            lens=al.GalaxyModel(redshift=0.5, mass=mass),
             source=al.GalaxyModel(
                 redshift=1.0,
                 pixelization=al.pix.Rectangular,
                 regularization=al.reg.Constant,
             ),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase1.optimizer.const_efficiency_mode = True
-    phase1.optimizer.n_live_points = 60
-    phase1.optimizer.sampling_efficiency = 0.8
+    phase1.search.const_efficiency_mode = True
+    phase1.search.n_live_points = 60
+    phase1.search.sampling_efficiency = 0.8
 
-    phase1.extend_with_multiple_hyper_phases(hyper_galaxy=True)
+    phase1.extend_with_multiple_hyper_phases(hyper_galaxies_search=True)
 
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5,
@@ -52,12 +52,12 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
                 hyper_galaxy=phase1.result.hyper_combined.instance.galaxies.source.hyper_galaxy,
             ),
         ),
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase2.optimizer.const_efficiency_mode = True
-    phase2.optimizer.n_live_points = 40
-    phase2.optimizer.sampling_efficiency = 0.8
+    phase2.search.const_efficiency_mode = True
+    phase2.search.n_live_points = 40
+    phase2.search.sampling_efficiency = 0.8
 
     return al.PipelineDataset(name, phase1, phase2)
 
