@@ -3,27 +3,27 @@ import autolens as al
 from test_autolens.integration.tests.imaging import runner
 
 test_type = "phase_features"
-test_name = "pixel_scale_interpolation_grid"
-data_type = "lens_sie__source_smooth"
-data_resolution = "lsst"
+test_name = "pixel_scales_interp"
+data_name = "lens_sie__source_smooth"
+instrument = "vro"
 
 
-def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
+def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalPowerLaw),
             source=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
-        pixel_scale_interpolation_grid=0.3,
-        non_linear_class=non_linear_class,
+        pixel_scales_interp=0.3,
+        search=search,
     )
 
-    phase1.optimizer.const_efficiency_mode = True
-    phase1.optimizer.n_live_points = 60
-    phase1.optimizer.sampling_efficiency = 0.8
+    phase1.search.const_efficiency_mode = True
+    phase1.search.n_live_points = 60
+    phase1.search.sampling_efficiency = 0.8
 
     return al.PipelineDataset(name, phase1)
 
