@@ -4,11 +4,11 @@ from test_autolens.integration.tests.imaging import runner
 
 test_type = "phase_features"
 test_name = "positions__offset_centre"
-data_type = "lens_sis__source_smooth__offset_centre"
-data_resolution = "lsst"
+data_name = "lens_sis__source_smooth__offset_centre"
+instrument = "vro"
 
 
-def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
+def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
     class LensPhase(al.PhaseImaging):
         def customize_priors(self, results):
 
@@ -19,18 +19,18 @@ def make_pipeline(name, phase_folders, non_linear_class=af.MultiNest):
 
     phase1 = LensPhase(
         phase_name="phase_1",
-        phase_folders=phase_folders,
+        folders=setup.folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.SphericalIsothermal),
             source=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
         positions_threshold=0.5,
-        non_linear_class=non_linear_class,
+        search=search,
     )
 
-    phase1.optimizer.const_efficiency_mode = True
-    phase1.optimizer.n_live_points = 30
-    phase1.optimizer.sampling_efficiency = 0.8
+    phase1.search.const_efficiency_mode = True
+    phase1.search.n_live_points = 30
+    phase1.search.sampling_efficiency = 0.8
 
     return al.PipelineDataset(name, phase1)
 
