@@ -1,5 +1,5 @@
 from autolens.fit.plotters import masked_imaging_fit_plotters
-from test import simulate_util
+from test_autolens.simulate.imaging import simulate_util
 
 # In this tutorial, we'll introduce a new pixelization, called an adaptive-pixelization. This pixelization doesn't use
 # uniform grid of rectangular pixels, but instead uses ir'Voronoi' pixels. So, why would we want to do that?
@@ -7,10 +7,10 @@ from test import simulate_util
 
 # Lets quickly remind ourselves of the image, and the 3.0" circular mask we'll use to mask it.
 imaging = simulate_util.load_test_imaging(
-    data_type="lens_light_dev_vaucouleurs", data_resolution="lsst"
+    data_name="lens_light_dev_vaucouleurs", instrument="vro"
 )
 mask = al.Mask.elliptical(
-    shape=imaging.shape,
+    shape=imaging.shape_2d,
     pixel_scales=imaging.pixel_scales,
     major_axis_radius=3.0,
     axis_ratio=1.0,
@@ -26,12 +26,12 @@ mask = al.Mask.elliptical(
 
 # The lines of code below do everything we're used to, that is, setup an image and its grid, mask it, trace it
 # via a tracer, setup the rectangular mapper, etc.
-lens_galaxy = al.Galaxy(
+lens_galaxy = al.Light(
     mass=al.mp.EllipticalIsothermal(
-        centre=(1.0, 1.0), einstein_radius=1.6, axis_ratio=0.7, phi=45.0
+        centre=(1.0, 1.0), einstein_radius=1.6, elliptical_comps=(0.17647, 0.0)
     )
 )
-source_galaxy = al.Galaxy(
+source_galaxy = al.Light(
     pixelization=al.pix.VoronoiMagnification(shape=(20, 20)),
     regularization=al.reg.instance(coefficient=1.0),
 )
@@ -42,14 +42,14 @@ tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
 fit = al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
 
 
-aplt_array.fit_imaging.subplot_imaging(
+aplt.FitImaging.subplot_fit_imaging(
     fit=fit, mask=True, include_image_plane_pix=True, aspect="auto"
 )
 
-aplt_array.fit_imaging.subplot_imaging(
+aplt.FitImaging.subplot_fit_imaging(
     fit=fit, mask=True, include_image_plane_pix=True, aspect="equal"
 )
 
-aplt_array.fit_imaging.subplot_imaging(
+aplt.FitImaging.subplot_fit_imaging(
     fit=fit, mask=True, include_image_plane_pix=True, aspect="square"
 )
