@@ -1,10 +1,11 @@
+import os
+import shutil
+from os import path
+
+import pytest
+from autoconf import conf
 import autolens as al
 from autolens.pipeline import visualizer as vis
-import os
-import pytest
-from os import path
-import shutil
-from autofit import conf
 
 directory = path.dirname(path.realpath(__file__))
 
@@ -82,7 +83,7 @@ class TestPhaseDataSetVisualizer:
         )
 
         assert plot_path + "subplots/subplot_tracer.png" in plot_patch.paths
-        assert plot_path + "ray_tracing/profile_image.png" in plot_patch.paths
+        assert plot_path + "ray_tracing/image.png" in plot_patch.paths
         assert plot_path + "ray_tracing/source_plane.png" in plot_patch.paths
         assert plot_path + "ray_tracing/convergence.png" in plot_patch.paths
         assert plot_path + "ray_tracing/potential.png" not in plot_patch.paths
@@ -96,12 +97,37 @@ class TestPhaseDataSetVisualizer:
 
         assert convergence.shape == (5, 5)
 
+    def test__visualize_stochastic_histogram(
+        self, masked_imaging_7x7, plot_path, plot_patch
+    ):
+
+        visualizer = vis.PhaseDatasetVisualizer(
+            masked_dataset=masked_imaging_7x7, image_path=plot_path
+        )
+
+        visualizer.visualize_stochastic_histogram(
+            log_evidences=[1.0, 2.0, 1.0, 2.0, 3.0, 2.5],
+            max_log_evidence=3.0,
+            during_analysis=True,
+        )
+        assert plot_path + "other/stochastic_histogram.png" not in plot_patch.paths
+
+        visualizer.visualize_stochastic_histogram(
+            log_evidences=[1.0, 2.0, 1.0, 2.0, 3.0, 2.5],
+            max_log_evidence=3.0,
+            during_analysis=False,
+        )
+        assert plot_path + "other/stochastic_histogram.png" in plot_patch.paths
+
 
 class TestPhaseImagingVisualizer:
     def test__visualizes_imaging_using_configs(
         self, masked_imaging_7x7, include_all, plot_path, plot_patch
     ):
 
+        if os.path.exists(plot_path):
+            shutil.rmtree(plot_path)
+
         visualizer = vis.PhaseImagingVisualizer(
             masked_dataset=masked_imaging_7x7, image_path=plot_path
         )
